#=====================================================================================================================#
# package      DE_EPAGES::ShopMigration::API::Constants
# state        public
# description  Constants of cartridge ShopMigration
#=====================================================================================================================#
package DE_EPAGES::ShopMigration::API::Constants;
use base Exporter;

use strict;
our @EXPORT_OK = qw(
    SHOPMIGRATION_NOT_PARTICIPATING
    SHOPMIGRATION_INITIAL_ALLOW
    SHOPMIGRATION_INITIAL_IN_PROGRESS
    SHOPMIGRATION_INITAL_PREPARED
    SHOPMIGRATION_INITAL_FAILED
    SHOPMIGRATION_FINAL_ALLOW
    SHOPMIGRATION_FINAL_IN_PROGRESS
    SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW
    SHOPMIGRATION_FINAL_DONE
    SHOPMIGRATION_FINAL_FAILED
    SHOPMIGRATION_ABORTED
    PREPSHOPS_FOLDER_ALIAS
    @SHOPMIGRATION_PREPSHOP_FEATURES
    %SHOPMIGRATION_PREPSHOP_MODIFIED_FEATURES
    %SHOPMIGRATION_SHOPTYPE_MAPPING
    BASIC_SHOP_DATA_ATTRIBUTES_GET
    BASIC_SHOP_DATA_ATTRIBUTES_SET
    BASIC_SHOP_DATA_LOCALIZEDATTRIBUTES
    SHOP_DATA_ATTRIBUTES_FOR_BASE_EXPORT
    SHOP_DATA_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT
    SHOP_DATA_SCRIBEATTRIBUTES_FOR_BASE_EXPORT
    SHOP_DATA_OBJECTATTRIBUTES_FOR_BASE_EXPORT
    SHOP_DATA_ATTRIBUTES_FOR_PREP_EXPORT
    SHOP_DATA_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT
    SHOP_DATA_OBJECTATTRIBUTES_FOR_PREP_EXPORT
    MAILTYPE_ATTRIBUTES_FOR_EXPORT
    MAILTYPE_ATTRIBUTES_FOR_IMPORT
    MAILTYPE_LOCALIZEDATTRIBUTES_FOR_EXPORT
    MAILTYPE_LOCALIZEDATTRIBUTES_FOR_IMPORT
    MAILTYPE_SCRIBEATTRIBUTES_FOR_EXPORT
    MAILTYPE_BOOLEAN_ATTRIBUTES_FOR_RESET
    MAILTYPE_LOCALIZEDATTRIBUTES_FOR_RESET
    @LEGELPAGES_ALIASES
    LEGALPAGE_ATTRIBUTES_FOR_BASE_EXPORT
    LEGALPAGE_ATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT
    LEGALPAGE_ATTRIBUTES_SCRIBEATTRIBUTES_FOR_BASE_EXPORT
    LEGALPAGE_ATTRIBUTES_FOR_PREP_EXPORT
    LEGALPAGE_ATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT
    CATEGORIES_ATTRIBUTES_FOR_EXPORT
    CATEGORIES_LOCALIZEDATTRIBUTES_FOR_EXPORT
    CATEGORIES_ATTRIBUTES_FOR_RESET
    CATEGORIES_LOCALIZEDATTRIBUTES_FOR_RESET
    CATEGORIES_ATTRIBUTES_FOR_IMPORT
    CATEGORIES_LOCALIZEDATTRIBUTES_FOR_IMPORT
    PRODUCTTYPES_ATTRIBUTES_FOR_EXPORT
    PRODUCTTYPES_LOCALIZEDATTRIBUTES_FOR_EXPORT
    PRODUCTTYPESATTRIBUTE_ATTRIBUTES_FOR_EXPORT
    PRODUCTTYPESATTRIBUTE_LOCALIZEDATTRIBUTES_FOR_EXPORT
    PRODUCTTYPESATTRIBUTE_BOOLEAN_ATTRIBUTES_FOR_RESET
    PRODUCTTYPESATTRIBUTE_LOCALIZEDATTRIBUTES_FOR_RESET
    PREDEFATTRIBUTES_ATTRIBUTES_FOR_EXPORT
    PREDEFATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_EXPORT
    PREDEFATTRIBUTES_OBJECT_ATTRIBUTES_FOR_EXPORT
    PRODUCTTYPE_SUPPORTED_ATTRIBUTE_TYPES
    PRODUCTS_ATTRIBUTES_FOR_PREP_EXPORT
    PRODUCTS_IMAGE_ATTRIBUTES
    PRODUCTS_OBJECTATTRIBUTES_FOR_PREP_EXPORT
    PRODUCTS_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT
    PRODUCTS_ATTRIBUTES_FOR_BASE_EXPORT
    PRODUCTS_OBJECTATTRIBUTES_FOR_BASE_EXPORT
    PRODUCTS_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT
    PRODUCTS_SCRIBEATTRIBUTES_FOR_BASE_EXPORT
    PRODUCTS_FILE_ATTRIBUTES
    PRODUCTS_SCALE_IMAGE_ATTRIBUTES
    PRODUCTS_ATTRIBUTES_DATETIME
    CUSTOMERGROUP_ATTRIBUTES
    CUSTOMERGROUP_LOCALIZEDATTRIBUTES
    PRICELIST_ATTRIBUTES
    PRICELIST_LOCALIZEDATTRIBUTES
    PRICELIST_SCALEPRICE_ATTRIBUTES
    PRICELIST_QUANTITYDISCOUNT_ATTRIBUTES
    PRICELIST_GLOBALVALUEDISCOUNT_ATTRIBUTES
    $EXPORT_FILES_AND_FILEATTRIBUTES
    CATEGORYPRODUCTMAPS_ATTRIBUTES
    CATEGORYPRODUCTMAPS_OBJECTATTRIBUTES
    CROSSSELLINGS_ATTRIBUTES
    CROSSSELLINGS_OBJECTATTRIBUTES
    EXPORT_IMPORT_ORDER

    MIGRATION_DIALOG_REPEAT_AFTER_DAYS

    $UNAVAILABLE_VIEWACTIONS_MAP
    $FILTER_SHORTURL

    MAX_IMAGE_FILENAME_LENGTH
);

use DE_EPAGES::ShopMigration::API::ShopMigrationConfig qw(GetPrepShopFeatures GetShopTypeMapping GetPrepShopModifiedFeatures);
use Readonly;
#=====================================================================================================================#
# global   SHOPMIGRATION_NOT_PARTICIPATING | (default) shop is not migratable or was not
#               yet checked for migratable status | integer
# global   SHOPMIGRATION_INITIAL_ALLOW | shop is migratable/show migrate button in MBO
# global   SHOPMIGRATION_INITIAL_IN_PROGRESS | initial migration is in progress/disable migrate button in MBO
# global   SHOPMIGRATION_INITAL_PREPARED | initial migration is done/show login button in MBO
# global   SHOPMIGRATION_INITAL_FAILED | initial migration failed due to some error
#              (e.g. NowShop could not be created or data import errors)
# global   SHOPMIGRATION_FINAL_ALLOW | allow final migration step/show button in MBO
# global   SHOPMIGRATION_FINAL_IN_PROGRESS | final migration is in progress
# global   SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW | final migration is done but shoptype needs to be changed by Site
# global   SHOPMIGRATION_FINAL_DONE | final migration is done for this shop
# global   SHOPMIGRATION_FINAL_FAILED | final migration step failed
# global   SHOPMIGRATION_ABORTED | migration aborted by merchant
#========================================================================================
use constant SHOPMIGRATION_NOT_PARTICIPATING => 0;
use constant SHOPMIGRATION_INITIAL_ALLOW => 1;
use constant SHOPMIGRATION_INITIAL_IN_PROGRESS => 2;
use constant SHOPMIGRATION_INITAL_PREPARED => 4;
use constant SHOPMIGRATION_INITAL_FAILED => 8;
use constant SHOPMIGRATION_FINAL_ALLOW => 16;
use constant SHOPMIGRATION_FINAL_IN_PROGRESS => 32;
use constant SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW => 64;
use constant SHOPMIGRATION_FINAL_DONE => 128;
use constant SHOPMIGRATION_FINAL_FAILED => 256;
use constant SHOPMIGRATION_ABORTED => 512;

#=====================================================================================================================#
# global    PREPSHOPS_FOLDER_ALIAS | alias of prepshops folder | string
#========================================================================================
use constant PREPSHOPS_FOLDER_ALIAS => 'PrepShops';

#=====================================================================================================================#
# global  @SHOPMIGRATION_PREPSHOP_FEATURES | array of initial prepshop features
#=====================================================================================================================#
our @SHOPMIGRATION_PREPSHOP_FEATURES = @{GetPrepShopFeatures()};

#=====================================================================================================================#
# global  @@SHOPMIGRATION_PREPSHOP_MODIFIED_FEATURES | array of modified/overwritten prepshop features
#=====================================================================================================================#
our %SHOPMIGRATION_PREPSHOP_MODIFIED_FEATURES = %{GetPrepShopModifiedFeatures()};

#=====================================================================================================================#
# global  %SHOPMIGRATION_SHOPTYPE_MAPPING | mapping for releated shoptypes (base -> now)
#=====================================================================================================================#
our %SHOPMIGRATION_SHOPTYPE_MAPPING = %{GetShopTypeMapping()};

#=====================================================================================================================#
# global  BASIC_SHOP_DATA_ATTRIBUTES_GET |
#          all attribute aliases to be exported on the BaseShop for creating a prepshop
#=====================================================================================================================#
use constant BASIC_SHOP_DATA_ATTRIBUTES_GET => [
    qw(
        Alias WebServerScriptNamePart CurrencyID LocaleID TaxModel InputTaxModel VATreleased
    ) ];

#=====================================================================================================================#
# global  BASIC_SHOP_DATA_ATTRIBUTES_SET |
#          all attribute aliases to be set on the PrepShop after creating it
#=====================================================================================================================#
use constant BASIC_SHOP_DATA_ATTRIBUTES_SET => [
    qw(
        CurrencyID LocaleID TaxModel InputTaxModel VATreleased
    ) ];

#=====================================================================================================================#
# global  BASIC_SHOP_DATA_LOCALIZEDATTRIBUTES  |
#          all attribute aliases to be exported on the BaseShop for creating a prepshop
#=====================================================================================================================#
use constant BASIC_SHOP_DATA_LOCALIZEDATTRIBUTES => [
    qw(
        Name
    ) ];

#=====================================================================================================================#
# global  SHOP_DATA_ATTRIBUTES_FOR_BASE_EXPORT | all attribute aliases to be exported on the BaseShop
#=====================================================================================================================#
use constant SHOP_DATA_ATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        MailFrom AcceptTac AcceptCustomerInformation DeliveryDimensionUnitInch UseProductZoom
        MinOrderAmount
    ) ];

#=====================================================================================================================#
# global  SHOP_DATA_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT | all localized attribute aliases to be exported on BaseShop
#=====================================================================================================================#
use constant SHOP_DATA_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        Name VATreleasedMessage Signature OrderDocumentsFooter OrderDocumentsInvoiceText1
        OrderDocumentsPackingSlipText1 OrderDocumentsCreditNoteText1
        AcceptTacText AcceptCustomerInformationText OrderProcessAddressText OrderProcessShippingText
        OrderProcessPaymentText OrderProcessCheckText OrderConfirmationText PriceTagInfoSingleProductNet
        PriceTagInfoSingleProductGross PriceTagInfoMultiProductNet PriceTagInfoMultiProductGross ReferencePriceText
    ) ];

#=====================================================================================================================#
# global  SHOP_DATA_SCRIBEATTRIBUTES_FOR_BASE_EXPORT | all localized attribute aliases that require a scribe conversion
#=====================================================================================================================#
use constant SHOP_DATA_SCRIBEATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        VATreleasedMessage Signature OrderDocumentsFooter OrderDocumentsInvoiceText1
        OrderDocumentsPackingSlipText1 OrderDocumentsCreditNoteText1
        AcceptTacText AcceptCustomerInformationText OrderProcessAddressText OrderProcessShippingText
        OrderProcessPaymentText OrderProcessCheckText OrderConfirmationText PriceTagInfoSingleProductNet
        PriceTagInfoSingleProductGross PriceTagInfoMultiProductNet PriceTagInfoMultiProductGross ReferencePriceText
    ) ];

#=====================================================================================================================#
# global  SHOP_DATA_OBJECTATTRIBUTES_FOR_BASE_EXPORT | all attribute aliases to be exported on PrepShop
#=====================================================================================================================#
use constant SHOP_DATA_OBJECTATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        NOT_USED_YET
    ) ];

#=====================================================================================================================#
# global  SHOP_DATA_ATTRIBUTES_FOR_PREP_EXPORT | all attribute aliases to be exported on PrepShop
#=====================================================================================================================#
use constant SHOP_DATA_ATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        UnityThemeStylePath MailFrom EmailEventsDisplayLogoUnity
        RegistrationSetVisibleFields RegistrationSetMandatoryFields BillingAddressSetVisibleFields
        BillingAddressSetMandatoryFields ShippingAddressSetVisibleFields ShippingAddressSetMandatoryFields
        AcceptTac AcceptCustomerInformation
        OrderDocumentsDisplayLogoUnity DeliveryDimensionUnitInch UseProductZoom
        UnityFacetedSearchFilterCategory UnityFacetedSearchFilterManufacturer UnityFacetedSearchFilterPriceRange
        UnitySeenAppIDs LastOrderUnitForProductCreation NextSteps UseUnityShopLogo
        MinOrderAmount
    ) ];

#=====================================================================================================================#
# global  SHOP_DATA_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT | all localized attribute aliases to be exported on PrepShop
#=====================================================================================================================#
use constant SHOP_DATA_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        Name VATreleasedMessage Signature
        OrderDocumentsFooter OrderDocumentsInvoiceText1 OrderDocumentsPackingSlipText1 OrderDocumentsCreditNoteText1
        AcceptTacText AcceptCustomerInformationText OrderProcessAddressText OrderProcessShippingText
        OrderProcessPaymentText OrderProcessCheckText
        ProductNoAddToBasketText ProductStockAvailableText ProductStockCriticalText
        UnityCrossSellingBoxHeadline BasketBelowText OrderConfirmationText PriceTagInfoSingleProductNet
        PriceTagInfoSingleProductGross PriceTagInfoMultiProductNet PriceTagInfoMultiProductGross ReferencePriceText
    ) ];

#=====================================================================================================================#
# global  SHOP_DATA_OBJECTATTRIBUTES_FOR_PREP_EXPORT | attributes that are objects and need to be converted to path strings
#=====================================================================================================================#
use constant SHOP_DATA_OBJECTATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        LastOrderUnitForProductCreation
    ) ];

#=====================================================================================================================#
# global  MAILTYPE_ATTRIBUTES_FOR_EXPORT | attributes to be exported by the mailtypes exporter
#=====================================================================================================================#
use constant MAILTYPE_ATTRIBUTES_FOR_EXPORT => [
    qw(
        Alias IsActive TO FROM CC BCC
    ) ];

#=====================================================================================================================#
# global  MAILTYPE_ATTRIBUTES_FOR_IMPORT | allowed attributes for the mailtype importer
#=====================================================================================================================#
use constant MAILTYPE_ATTRIBUTES_FOR_IMPORT => [
    qw(
        Alias IsActive TO FROM CC BCC OrderDocumentPdfAttachment
        AttachCustomerInformationPDF UnityAttachLegalDocumentsPDF
    ) ];

#=====================================================================================================================#
# global  MAILTYPE_LOCALIZEDATTRIBUTES_FOR_EXPORT |  localizedattributes to be exported by the mailtypes exporter
#=====================================================================================================================#
use constant MAILTYPE_LOCALIZEDATTRIBUTES_FOR_EXPORT => [
    qw(
        Subject Header
    ) ];

#=====================================================================================================================#
# global  MAILTYPE_LOCALIZEDATTRIBUTES_FOR_IMPORT |  allowed localizedattributes for the mailtype importer
#=====================================================================================================================#
use constant MAILTYPE_LOCALIZEDATTRIBUTES_FOR_IMPORT => [
    qw(
        Subject Header AdditionalText

    ) ];

#=====================================================================================================================#
# global  MAILTYPE_SCRIBEATTRIBUTES_FOR_EXPORT | all localizedattributes  that require a scribe conversion
#=====================================================================================================================#
use constant MAILTYPE_SCRIBEATTRIBUTES_FOR_EXPORT => [
    qw(
        Header
    ) ];


#=====================================================================================================================#
# global  MAILTYPE_BOOLEAN_ATTRIBUTES_FOR_RESET |  boolean attributes to be exported with default value on export
#=====================================================================================================================#
use constant MAILTYPE_BOOLEAN_ATTRIBUTES_FOR_RESET => [
    qw(
        OrderDocumentPdfAttachment AttachCustomerInformationPDF
    ) ];

#=====================================================================================================================#
# global  MAILTYPE_LOCALIZEDATTRIBUTES_FOR_RESET |  localizedattributes to be exported with default value on export
#=====================================================================================================================#
use constant MAILTYPE_LOCALIZEDATTRIBUTES_FOR_RESET => [
    qw(
        AdditionalText
    ) ];

#=====================================================================================================================#
# global  @LEGELPAGES_ALIASES | aliases of legal pages
#=====================================================================================================================#
our @LEGELPAGES_ALIASES = qw(CustomerInformation CookiePolicy Imprint PrivacyPolicy ShippingAndPaymentInformation TermsAndConditions);

#=====================================================================================================================#
# global  LEGALPAGE_ATTRIBUTES_FOR_BASE_EXPORT | attributes to be exported by the legalpages exporter
#=====================================================================================================================#
use constant LEGALPAGE_ATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        Alias
    ) ];

#=====================================================================================================================#
# global  LEGALPAGE_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT | localizedattributes to be exported by the legalpages exporter
#=====================================================================================================================#
use constant LEGALPAGE_ATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        NameOrAlias Description Text URI
    ) ];

#=====================================================================================================================#
# global  LEGALPAGE_ATTRIBUTES_SCRIBEATTRIBUTES_FOR_BASE_EXPORT | localizedattributes that require a scribe conversion
#=====================================================================================================================#
use constant LEGALPAGE_ATTRIBUTES_SCRIBEATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        Text
    ) ];

#=====================================================================================================================#
# global  LEGALPAGE_ATTRIBUTES_FOR_PREP_EXPORT |
#=====================================================================================================================#
use constant LEGALPAGE_ATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        Alias IsVisible
    ) ];


#=====================================================================================================================#
# global  LEGALPAGE_ATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT |
#=====================================================================================================================#
use constant LEGALPAGE_ATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        Text URI
    ) ];

#=====================================================================================================================#
# global  CATEGORIES_ATTRIBUTES_FOR_EXPORT | allowed attributes for the categories exporter
#=====================================================================================================================#
use constant CATEGORIES_ATTRIBUTES_FOR_EXPORT => [
    qw(
        Alias Position Parent IsVisible VisibleInNavigation GUID
    ) ];

#=====================================================================================================================#
# global  CATEGORIES_LOCALIZEDATTRIBUTES_FOR_EXPORT | allowed localizedattributes for the categories exporter
#=====================================================================================================================#
use constant CATEGORIES_LOCALIZEDATTRIBUTES_FOR_EXPORT => [
    qw(
        Name
    ) ];

#=====================================================================================================================#
# global  CATEGORIES_ATTRIBUTES_FOR_RESET | attributes to be exported with default value on export
#=====================================================================================================================#
use constant CATEGORIES_ATTRIBUTES_FOR_RESET => [
    qw(
        ImageSmall ImageMedium ImageInformations Image1 Image2
    ) ];

#=====================================================================================================================#
# global  CATEGORIES_LOCALIZEDATTRIBUTES_FOR_RESET | localizedattributes to be exported with default value on export
#=====================================================================================================================#
use constant CATEGORIES_LOCALIZEDATTRIBUTES_FOR_RESET => [
    qw(
        Title Description Text NavigationCaption Keywords SEOQuality Text1 Text2 Text3
    ) ];

#=====================================================================================================================#
# global  CATEGORIES_ATTRIBUTES_FOR_IMPORT | allowed attributes for the categories importer
#=====================================================================================================================#
use constant CATEGORIES_ATTRIBUTES_FOR_IMPORT => [
    qw(
        Alias Position IsVisible VisibleInNavigation
        ImageSmall ImageMedium ImageInformations Image1 Image2
    ) ];

#=====================================================================================================================#
# global  CATEGORIES_LOCALIZEDATTRIBUTES_FOR_IMPORT | allowed localizeddattributes for the categories importer
#=====================================================================================================================#
use constant CATEGORIES_LOCALIZEDATTRIBUTES_FOR_IMPORT => [
    qw(
        Name Title Description Text NavigationCaption Keywords SEOQuality Text1 Text2 Text3
    ) ];

#=====================================================================================================================#
# global  PRODUCTTYPES_ATTRIBUTES_FOR_EXPORT | allowed attributes for the product types exporter
#=====================================================================================================================#
use constant PRODUCTTYPES_ATTRIBUTES_FOR_EXPORT => [
    qw(
        Alias Position
    ) ];

#=====================================================================================================================#
# global  CATEGORIES_LOCALIZEDATTRIBUTES_FOR_EXPORT | allowed localizedattributes for the product types exporter
#=====================================================================================================================#
use constant PRODUCTTYPES_LOCALIZEDATTRIBUTES_FOR_EXPORT => [
    qw(
        Name
    ) ];

#=====================================================================================================================#
# global  PRODUCTTYPESATTRIBUTE_ATTRIBUTES_FOR_EXPORT | allowed attributes for the product types
#=====================================================================================================================#
use constant PRODUCTTYPESATTRIBUTE_ATTRIBUTES_FOR_EXPORT => [
    qw(
        Alias Position IsVisible Type IsHTML ShowInOwnTab IsSearchFilter IsUserDefined IsObject
    ) ];

#=====================================================================================================================#
# global  PRODUCTTYPESATTRIBUTE_LOCALIZEDATTRIBUTES_FOR_EXPORT | allowed attributes for the product types
#=====================================================================================================================#
use constant PRODUCTTYPESATTRIBUTE_LOCALIZEDATTRIBUTES_FOR_EXPORT => [
    qw(
        Name Description
    ) ];

#=====================================================================================================================#
# global  PRODUCTTYPESATTRIBUTE_ATTRIBUTES_FOR_RESET | allowed attributes for prod. attributes
#=====================================================================================================================#
use constant PRODUCTTYPESATTRIBUTE_BOOLEAN_ATTRIBUTES_FOR_RESET => [
    qw(
        IsHTML ShowInOwnTab IsSearchFilter
    ) ];

#=====================================================================================================================#
# global  PRODUCTTYPESATTRIBUTE_LOCALIZEDATTRIBUTES_FOR_RESET | allowed localized attributes for prod. attributes
#=====================================================================================================================#
use constant PRODUCTTYPESATTRIBUTE_LOCALIZEDATTRIBUTES_FOR_RESET => [
    qw(
        Description
    ) ];

#=====================================================================================================================#
# global  PREDEFATTRIBUTES_ATTRIBUTES_FOR_EXPORT | allowed attributes for the predef attributes
#=====================================================================================================================#
use constant PREDEFATTRIBUTES_ATTRIBUTES_FOR_EXPORT => [
    qw(
        Alias Position Attribute
    ) ];

#=====================================================================================================================#
# global  PREDEFATTRIBUTES_OBJECT_ATTRIBUTES_FOR_EXPORT | allowed attributes for the predef attributes
#=====================================================================================================================#
use constant PREDEFATTRIBUTES_OBJECT_ATTRIBUTES_FOR_EXPORT => [
    qw(
        Attribute
    ) ];

#=====================================================================================================================#
# global  PREDEFATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_EXPORT | allowed attributes for the predef localized attributes
#=====================================================================================================================#
use constant PREDEFATTRIBUTES_LOCALIZEDATTRIBUTES_FOR_EXPORT => [
    qw(
        ValueLocString
    ) ];

#=====================================================================================================================#
# global  PRODUCTTYPE_SUPPORTED_ATTRIBUTE_TYPES | allowed types for user defined product type attributes
#=====================================================================================================================#
use constant PRODUCTTYPE_SUPPORTED_ATTRIBUTE_TYPES => [
    qw(
        String PreDefString LocalizedString PreDefLocalizedString  Integer Float Boolean Money DateTime Date Time
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_ATTRIBUTES_FOR_PREP_EXPORT | allowed attributes for the products exporter (BaseAttributes)
#=====================================================================================================================#
use constant PRODUCTS_ATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        Alias Position IsVisible
        Weight RefAmount RefContentAmount
        Manufacturer ManufacturerSKU DeliveryPeriod Length Height Width
        UPCEAN ListPrices IsDefault
        ImageLarge ImagesSlideShowString
        ImageMedium ImageMediumLarge ImageMediumSmall ImageSmall ImageThumbnail ImageHotDeal
        EnergyLabelsString EnergyLabelSourceFile
        EnergyLabelHighestEfficiencyClass
        HasSubOwnPrices
        Class SuperProduct
        TaxClass TaxClassDigital
        WeightUnit RefUnit OrderUnit
        IsNew IsDailyPrice PriceQuantity MinOrder IntervalOrder
        IsAvailable  AvailabilityDate
        NewnessDate RatingAverage EcoParticipationCategory ExpiryDate GUID
        SelectedVariations
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_ATTRIBUTES_DATETIME | these attributes need to be converted from/to string manually
#=====================================================================================================================#
use constant PRODUCTS_ATTRIBUTES_DATETIME => [
    qw(
        NewnessDate
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_IMAGE_ATTRIBUTES | these attributes must be checked for valid filenames
#=====================================================================================================================#
use constant PRODUCTS_IMAGE_ATTRIBUTES => [
    qw(
        ImageLarge ImagesSlideShowString ImageMedium ImageMediumLarge ImageMediumSmall ImageSmall ImageThumbnail ImageHotDeal
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_OBJECTATTRIBUTES_FOR_PREP_EXPORT | allowed attributes for the products exporter (Objects)
#=====================================================================================================================#
use constant PRODUCTS_OBJECTATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        Class SuperProduct
        TaxClass TaxClassDigital
        WeightUnit RefUnit OrderUnit
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT | allowed localizedattributes for the products exporter/importer
#=====================================================================================================================#
use constant PRODUCTS_LOCALIZEDATTRIBUTES_FOR_PREP_EXPORT => [
    qw(
        Name Keywords MainCharacteristics
        _ProductDataSheet
        ProductVideoProvider
        Description Text
        Title  AvailabilityComment
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_ATTRIBUTES_FOR_BASE_EXPORT | allowed attributes for the products exporter/importer
#=====================================================================================================================#
use constant PRODUCTS_ATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        Alias Position IsVisible
        Weight RefAmount RefContentAmount
        Manufacturer ManufacturerSKU DeliveryPeriod Length Height Width
        ImageLarge ImagesSlideShowString
        UPCEAN ListPrices IsDefault
        EnergyLabelsString EnergyLabelSourceFile
        EnergyLabelHighestEfficiencyClass
        HasSubOwnPrices
        Class SuperProduct
        TaxClass TaxClassDigital
        WeightUnit RefUnit OrderUnit
        OrderUnit PriceQuantity
        SelectedVariations
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_OBJECTATTRIBUTES_FOR_BASE_EXPORT | allowed attributes for the products exporter (Objects)
#=====================================================================================================================#
use constant PRODUCTS_OBJECTATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        Class SuperProduct
        TaxClass TaxClassDigital
        WeightUnit RefUnit OrderUnit
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT | allowed localizeddattributes for the products exporter/importer
#=====================================================================================================================#
use constant PRODUCTS_LOCALIZEDATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        Name Keywords MainCharacteristics
        _ProductDataSheet
        Description Text
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_SCRIBEATTRIBUTES_FOR_BASE_EXPORT | all attribute aliases that require a scribe conversion
#=====================================================================================================================#
use constant PRODUCTS_SCRIBEATTRIBUTES_FOR_BASE_EXPORT => [
    qw(
        Description
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_FILE_ATTRIBUTES | these attributes contain files that need to be saved separately
#=====================================================================================================================#
use constant PRODUCTS_FILE_ATTRIBUTES => [
    qw(
        ImageLarge EnergyLabelSourceFile ImagesSlideShowString _ProductDataSheet
        ImageMedium ImageMediumLarge ImageMediumSmall ImageSmall ImageThumbnail ImageHotDeal
    ) ];

#=====================================================================================================================#
# global  PRODUCTS_SCALE_IMAGE_ATTRIBUTES | these attributes contain files that need to be saved separately
#=====================================================================================================================#
use constant PRODUCTS_SCALE_IMAGE_ATTRIBUTES => [
    qw(
        ImageLarge  ImagesSlideShowString
    ) ];

#=====================================================================================================================#
# global  CUSTOMERGROUP_ATTRIBUTES | allowed attributes for customer group export/import
#=====================================================================================================================#
use constant CUSTOMERGROUP_ATTRIBUTES => [
    qw(
        Alias IsNonMemberDefault  IsNewMemberDefault
    ) ];

#=====================================================================================================================#
# global  CUSTOMERGROUP_LOCALIZEDATTRIBUTES | allowed localizedattributes for the customer group to be imported/exported
#=====================================================================================================================#
use constant CUSTOMERGROUP_LOCALIZEDATTRIBUTES => [
    qw(
        Name
    ) ];

#=====================================================================================================================#
# global  PRICELIST_ATTRIBUTES | allowed attributes for the price list to be exported/imported
#=====================================================================================================================#
use constant PRICELIST_ATTRIBUTES => [
    qw(
        Alias CurrencyID
    ) ];

#=====================================================================================================================#
# global  PRICELIST_LOCALIZEDATTRIBUTES | allowed localizedattributes for the price list to be exported/imported
#=====================================================================================================================#
use constant PRICELIST_LOCALIZEDATTRIBUTES => [
    qw(
        Name
    ) ];

#=====================================================================================================================#
# global  PRICELIST_SCALEPRICE__ATTRIBUTES | allowed attributes for the scale prices to be exported/imported
#=====================================================================================================================#
use constant PRICELIST_SCALEPRICE_ATTRIBUTES => [
    qw(
        RelativePath PriceListAlias Quantity Price
    ) ];

#=====================================================================================================================#
# global  PRICELIST_QUANTITYDISCOUNT_ATTRIBUTES | allowed attributes for the quantity discounts to be exported/imported
#=====================================================================================================================#
use constant PRICELIST_QUANTITYDISCOUNT_ATTRIBUTES => [
    qw(
        RelativePath PriceListAlias Quantity Discount
    ) ];

#=====================================================================================================================#
# global  PRICELIST_GLOBALVALUEDISCOUNT_ATTRIBUTES | allowed attributes for the global value discount to be exported/imported
#=====================================================================================================================#
use constant PRICELIST_GLOBALVALUEDISCOUNT_ATTRIBUTES => [
    qw(
        PriceListAlias Value Discount DiscountAbsolute
    ) ];

#=====================================================================================================================#
# global  $EXPORT_FILES_AND_FILEATTRIBUTES | controls whatever files and fileattributes are exported
#=====================================================================================================================#
our $EXPORT_FILES_AND_FILEATTRIBUTES = 1;

#=====================================================================================================================#
# global  CATEGORYPRODUCTMAPS_ATTRIBUTES | allowed attributes for the categoryproductmaps export/import
#=====================================================================================================================#
use constant CATEGORYPRODUCTMAPS_ATTRIBUTES => [
    qw(
        Category Product Position PositionCategory
    ) ];

#=====================================================================================================================#
# global  CATEGORYPRODUCTMAPS_OBJECTATTRIBUTES |
#                              categoryproductmaps attributes that are objects and need to be converted to path strings
#=====================================================================================================================#
use constant CATEGORYPRODUCTMAPS_OBJECTATTRIBUTES => [
    qw(
        Product Category
    ) ];

#=====================================================================================================================#
# global  CROSSSELLINGS_ATTRIBUTES | allowed attributes for the cross selling export/import
#=====================================================================================================================#
use constant CROSSSELLINGS_ATTRIBUTES => [
    qw(
        Product TargetProduct Position
    ) ];

#=====================================================================================================================#
# global  CROSSSELLINGS_OBJECTATTRIBUTES |
#                              cross selling attributes that are objects and need to be converted to path strings
#=====================================================================================================================#
use constant CROSSSELLINGS_OBJECTATTRIBUTES => [
    qw(
        Product TargetProduct
    ) ];

#=====================================================================================================================#
# global  EXPORT_IMPORT_ORDER |
#          contains the order of which shop objects are exported/imported
#=====================================================================================================================#
use constant EXPORT_IMPORT_ORDER => [
    qw(
        ShopData MailTypes LegalPages Categories ProductTypes Products CategoryProductMaps CrossSellings
        CustomerGroups PriceLists PriceListScalePrices PriceListQuantityDiscounts PriceListGlobalValueDiscounts
    ) ];

#========================================================================================
# global       MIGRATION_DIALOG_REPEAT_AFTER_DAYS | number of days
#                   the migration info dialog is diplayed again | integer
#========================================================================================
use constant MIGRATION_DIALOG_REPEAT_AFTER_DAYS => 7;


#=====================================================================================================================#
# global  UNAVAILABLE_VIEWACTIONS_MAP | ViewActions, which are not available for PrepShops, and necessary attributes
#=====================================================================================================================#
Readonly our $UNAVAILABLE_VIEWACTIONS_MAP => {
    'UnityMBO-ViewProductPortals' => {
        'translationKey' => 'ProductPortals',
        'translationCartridge' => 'DE_EPAGES::ProductPortal',
        'mboMenuEntry' => 'Menu-Marketing',
        'mboSubMenuEntry' => 'MenuItem-ProductPortals',
        'helpCenterLink' => 'product-portals',
    },
    'UnityMBO-ViewCouponCampaigns' => {
        'translationKey' => 'Coupons',
        'translationCartridge' => 'DE_EPAGES::Dictionary',
        'mboMenuEntry' => 'Menu-Marketing',
        'mboSubMenuEntry' => 'MenuItem-CouponCampaigns',
        'helpCenterLink' => 'coupon-campaigns',
    },
    'UnityMBO-ViewGoogleSearch' => {
        'translationKey' => 'Google',
        'translationCartridge' => 'DE_EPAGES::Google',
        'mboMenuEntry' => 'Menu-Marketing',
        'mboSubMenuEntry' => 'MenuItem-Google',
        'helpCenterLink' => 'google'
    },
    'UnityMBO-ViewAmazonPortalList' => {
        'translationKey' => 'Amazon',
        'translationCartridge' => 'DE_EPAGES::Amazon',
        'mboMenuEntry' => 'Menu-Marketing',
        'mboSubMenuEntry' => 'MenuItem-Amazon',
        'helpCenterLink' => 'amazon'
    },
    'UnityMBO-ViewEbayAuctions' => {
        'translationKey' => 'Ebay',
        'translationCartridge' => 'DE_EPAGES::Ebay',
        'mboMenuEntry' => 'Menu-Marketing',
        'mboSubMenuEntry' => 'MenuItem-EbayOffers',
        'helpCenterLink' => 'ebay'
    },
    'UnityMBO-ViewTrustedShopsCertificates' => {
        'translationKey' => 'TrustedShopsTitle',
        'translationCartridge' => 'DE_EPAGES::TrustedShops',
        'mboMenuEntry' => 'Menu-Marketing',
        'mboSubMenuEntry' => 'MenuItem-TrustedShops',
        'helpCenterLink' => 'trusted-shops'
    },
    'UnityMBO-ViewAppStore' => {
        'translationKey' => 'AppsTitle',
        'translationCartridge' => 'DE_EPAGES::AppStore',
        'mboMenuEntry' => 'MenuItem-Apps',
        'helpCenterLink' => 'apps'
    },
    'UnityMBO-ViewStatusGeneral' => {
        'translationKey' => 'General',
        'translationCartridge' => 'DE_EPAGES::Dictionary',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-ShopStatus',
        'helpCenterLink' => 'general-settings'
    },
    'UnityMBO-ViewTaxMatrix' => {
        'translationKey' => 'Taxes',
        'translationCartridge' => 'DE_EPAGES::Tax',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-TaxMatrix',
        'helpCenterLink' => 'tax'
    },
    'UnityMBO-ViewShippingList' => {
        'translationKey' => 'Shipping',
        'translationCartridge' => 'DE_EPAGES::Dictionary',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-ShippingList',
        'helpCenterLink' => 'shipping'
    },
    'UnityMBO-ViewPaymentList' => {
        'translationKey' => 'PaymentSettings',
        'translationCartridge' => 'DE_EPAGES::Payment',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'INC-MenuItem-Payment',
        'helpCenterLink' => 'payment'
    },
    'UnityMBO-ViewLanguages' => {
        'translationKey' => 'Internationalisation',
        'translationCartridge' => 'DE_EPAGES::Shop',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-CountrySettings',
        'helpCenterLink' => 'internationalisation'
    },
    'UnityMBO-ViewCountries' => {
        'translationKey' => 'Internationalisation',
        'translationCartridge' => 'DE_EPAGES::Shop',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-CountrySettings',
        'helpCenterLink' => 'internationalisation'
    },
    'UnityMBO-SearchOrders' => {
        'translationKey' => 'Orders',
        'translationCartridge' => 'DE_EPAGES::Order',
        'mboMenuEntry' => 'Menu-Orders',
        'mboSubMenuEntry' => 'MenuItem-Orders',
        'helpCenterLink' => 'order-management'
    },
    'UnityMBO-ViewCustomers' => {
        'translationKey' => 'Customers',
        'translationCartridge' => 'DE_EPAGES::Customers',
        'mboMenuEntry' => 'Menu-Customers',
        'mboSubMenuEntry' => 'MenuItem-Customers',
        'helpCenterLink' => 'customer-management'
    },
    'UnityMBO-ViewCustomerGroups' => {
        'translationKey' => 'CustomerGroups',
        'translationCartridge' => 'DE_EPAGES::Customers',
        'mboMenuEntry' => 'Menu-Customers',
        'mboSubMenuEntry' => 'MenuItem-CustomerGroups',
        'helpCenterLink' => 'customer-management'
    },
    'UnityMBO-ViewNumberFormats' => {
        'translationKey' => 'General',
        'translationCartridge' => 'DE_EPAGES::Shop',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-ShopStatus',
        'helpCenterLink' => 'number-formats'
    },
    'UnityMBO-ViewTaxModel' => {
        'translationKey' => 'Taxes',
        'translationCartridge' => 'DE_EPAGES::Tax',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-TaxModel',
        'helpCenterLink' => 'tax'
    },
    'UnityMBO-ViewTaxMatrix' => {
        'translationKey' => 'Taxes',
        'translationCartridge' => 'DE_EPAGES::Tax',
        'mboMenuEntry' => 'Menu-Settings',
        'mboSubMenuEntry' => 'MenuItem-TaxMatrix',
        'helpCenterLink' => 'tax'
    }
};

Readonly::Scalar our $FILTER_SHORTURL =>
    qr/
        ^
            [lcp]             # categories, legal pages, products
            [\/]              # followed by slash
    /x;

# UNITY-6990 Shorten image filenames on PrepShop Migration (image service issue)
use constant MAX_IMAGE_FILENAME_LENGTH => 60;

1;
