#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::ProductInventoryDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class that wraps product balance info
#               See Responses > 200 RESPONSE SCHEMA in https://developer.zettle.com/docs/api/inventory-v3/reference#getStockForProducts
#               See Responses > 200 RESPONSE SCHEMA in https://developer.zettle.com/docs/api/inventory-v3/reference#getStockForInventory
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::ProductInventoryDTO;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::ProductInventoryDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::ProductInventoryDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;

}

#========================================================================================
# input        $OrganizationUuid | The organization UUID | string
#----------------------------------------------------------------------------------------
# return       $OrganizationUuid | Current organization UUID if $OrganizationUuid parameter is not provided | string
#========================================================================================
sub organizationUuid {
    my $self = shift;
    my ($OrganizationUuid) = @_;
    return $self->{'organizationUuid'} unless (defined($OrganizationUuid));
    $self->{'organizationUuid'} = $OrganizationUuid;
}

#========================================================================================
# input        $InventoryUuid | The UUID of the inventory that the variant belongs to | string
#----------------------------------------------------------------------------------------
# return       $InventoryUuid | Current organization UUID if $InventoryUuid parameter is not provided | string
#========================================================================================
sub inventoryUuid {
    my $self = shift;
    my ($InventoryUuid) = @_;
    return $self->{'inventoryUuid'} unless (defined($InventoryUuid));
    $self->{'inventoryUuid'} = $InventoryUuid;
}

#========================================================================================
# input        $ProductUuid | The UUID of the product that the variant belongs to | string
#----------------------------------------------------------------------------------------
# return       $ProductUuid | Current product UUID if $ProductUuid parameter is not provided | string
#========================================================================================
sub productUuid {
    my $self = shift;
    my ($ProductUuid) = @_;
    return $self->{'productUuid'} unless (defined($ProductUuid));
    $self->{'productUuid'} = $ProductUuid;
}

#========================================================================================
# input        $VariantUuid | The UUID of the variant | string
#----------------------------------------------------------------------------------------
# return       $VariantUuid | Current variant UUID if $VariantUuid parameter is not provided | string
#========================================================================================
sub variantUuid {
    my $self = shift;
    my ($VariantUuid) = @_;
    return $self->{'variantUuid'} unless (defined($VariantUuid));
    $self->{'variantUuid'} = $VariantUuid;
}

#========================================================================================
# input        $Balance | The stock level of the variant | int
#----------------------------------------------------------------------------------------
# return       $Balance | Current stock level if $Balance parameter is not provided | int
#========================================================================================
sub balance {
    my $self = shift;
    my ($Balance) = @_;
    return $self->{'balance'} unless (defined($Balance));
    $self->{'balance'} = $Balance;
}

#========================================================================================
# input        $LowStockLevel | A low stock level indicates that the stock needs to be refilled before it becomes empty | int
#----------------------------------------------------------------------------------------
# return       $LowStockLevel | Current low stock level if $LowStockLevel parameter is not provided | int
#========================================================================================
sub lowStockLevel {
    my $self = shift;
    my ($LowStockLevel) = @_;
    return $self->{'lowStockLevel'} unless (defined($LowStockLevel));
    $self->{'lowStockLevel'} = $LowStockLevel;
}

#========================================================================================
# input        $LowStockAlert | It indicates whether an alert will be triggered in the Zettle Go app
#                                when the low stock level is passed. This behaviour may change in the future | bool
#----------------------------------------------------------------------------------------
# return       $LowStockAlert | Current alert status if $LowStockAlert parameter is not provided | bool
#========================================================================================
sub lowStockAlert {
    my $self = shift;
    my ($LowStockAlert) = @_;
    return $self->{'lowStockAlert'} unless (defined($LowStockAlert));
    $self->{'lowStockAlert'} = $LowStockAlert;
}

#========================================================================================
# input        $Updated | The updated field indicates the time when the data is updated (date-time) | string
#----------------------------------------------------------------------------------------
# return       $Updated | Current updated date if $Updated parameter is not provided (i.e: 2019-08-24T14:15:22Z) | string
#========================================================================================
sub updated {
    my $self = shift;
    my ($Updated) = @_;
    return $self->{'updated'} unless (defined($Updated));
    $self->{'updated'} = $Updated;
}

#========================================================================================
# input        $Checksum | The checksum is a simple identifier that you should only use to deduplicate
#                           possible items in a paginated response. It is only used for comparing with
#                           the previously loaded page to identify duplicate items | string
#----------------------------------------------------------------------------------------
# return       $Checksum | Current data if $Checksum parameter is not provided | string
#========================================================================================
sub checksum {
    my $self = shift;
    my ($Checksum) = @_;
    return $self->{'checksum'} unless (defined($Checksum));
    $self->{'checksum'} = $Checksum;
}

#========================================================================================
# function     fromHash
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ProductInventoryDTO = DE_EPAGES::Zettle::API::WebService::DTO::ProductInventoryDTO->fromHash($hProductBalance);
#----------------------------------------------------------------------------------------
# description  Parse product balance info and return a ProductInventoryDTO object.
#----------------------------------------------------------------------------------------
# input        $hProductBalance | Product balance with following keys:
#               <ul>
#                   <li>organizationUuid - organization UUID - string
#                   <li>inventoryUuid - UUID of the inventory that the variant belongs to - string
#                   <li>productUuid - UUID of the product that the variant belongs to - string
#                   <li>variantUuid - UUID of the variant - string
#                   <li>balance - stock level of the variant - int
#                   <li>lowStockLevel - low stock level indicates that the stock needs to be refilled before it becomes empty - int
#                   <li>lowStockAlert - indicates whether an alert will be triggered in the Zettle Go app when the low stock level is passed - bool
#                   <li>updated - the time when the data is updated - string
#                   <li>checksum - used for comparing duplicates in paginated responses - string
#               </ul> | ref.hash
#----------------------------------------------------------------------------------------
# return       $ProductInventoryDTO | a ProductInventoryDTO object | DE_EPAGES::Zettle::API::WebService::DTO::ProductInventoryDTO
#========================================================================================
sub fromHash {
    my $class = shift;
    my ($hProductBalance) = @_;

    my $ProductInventoryDTO = $class->new();
    $ProductInventoryDTO->organizationUuid($hProductBalance->{'organizationUuid'});
    $ProductInventoryDTO->inventoryUuid($hProductBalance->{'inventoryUuid'});
    $ProductInventoryDTO->productUuid($hProductBalance->{'productUuid'});
    $ProductInventoryDTO->variantUuid($hProductBalance->{'variantUuid'});
    $ProductInventoryDTO->balance($hProductBalance->{'balance'});
    $ProductInventoryDTO->lowStockLevel($hProductBalance->{'lowStockLevel'});
    $ProductInventoryDTO->lowStockAlert($hProductBalance->{'lowStockAlert'});
    $ProductInventoryDTO->updated($hProductBalance->{'updated'});
    $ProductInventoryDTO->checksum($hProductBalance->{'checksum'});

    return $ProductInventoryDTO;
}

1;
